@@ -1,5 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+#
 def file_lines(path,compress=False):
     """Replicates the IDL FILE_LINES() function.
 
@@ -29,11 +31,13 @@ def file_lines(path,compress=False):
 
     Examples
     --------
-    >>> pydl.file_lines('my-one-line-file.txt')
-    1
+    >>> from pydl import file_lines
+    >>> from os.path import dirname, join
+    >>> file_lines(join(dirname(__file__),'tests','t','this-file-contains-42-lines.txt'))
+    42
     """
     scalar = False
-    if isinstance(path, str):
+    if isinstance(path, str) or isinstance(path, unicode):
         working_path = [path]
         scalar = True
     else:
@@ -42,8 +46,14 @@ def file_lines(path,compress=False):
     for filename in working_path:
         if compress:
             import gzip
-            with gzip.open(filename) as f:
+            from sys import version_info
+            if version_info[0] == 2 and version_info[1] < 7:
+                f = gzip.open(filename)
                 lines.append(len(f.readlines()))
+                f.close()
+            else:
+                with gzip.open(filename) as f:
+                    lines.append(len(f.readlines()))
         else:
             with open(filename) as f:
                 lines.append(len(f.readlines()))
