@@ -3,5 +3,5 @@
 """
 This subpackage corresponds to the astro directory in the Goddard utilities.
 """
-from gcirc import gcirc
-from get_juldate import get_juldate
+from .gcirc import gcirc
+from .get_juldate import get_juldate
