@@ -3,7 +3,7 @@
 """
 This subpackage corresponds to the bspline directory of idlutils.
 """
-from bspline import bspline
-from cholesky_band import cholesky_band
-from cholesky_solve import cholesky_solve
-from iterfit import iterfit
+from .bspline import bspline
+from .cholesky_band import cholesky_band
+from .cholesky_solve import cholesky_solve
+from .iterfit import iterfit
