@@ -3,6 +3,6 @@
 """
 This subpackage corresponds to the mangle directory of idlutils.
 """
-from is_cap_used import is_cap_used
-from read_fits_polygons import read_fits_polygons
-from set_use_caps import set_use_caps
+from .is_cap_used import is_cap_used
+from .read_fits_polygons import read_fits_polygons
+from .set_use_caps import set_use_caps
