@@ -3,7 +3,7 @@
 """
 This subpackage corresponds to the math directory of idlutils.
 """
-from computechi2 import computechi2
-from djs_median import djs_median
-from djs_reject import djs_reject
-from find_contiguous import find_contiguous
+from .computechi2 import computechi2
+from .djs_median import djs_median
+from .djs_reject import djs_reject
+from .find_contiguous import find_contiguous
