@@ -3,7 +3,7 @@
 """
 This subpackage corresponds to the spheregroup directory of idlutils.
 """
-from chunks import chunks
-from groups import groups
-from spheregroup import spheregroup
-from spherematch import spherematch
+from .chunks import chunks
+from .groups import groups
+from .spheregroup import spheregroup
+from .spherematch import spherematch
