@@ -8,9 +8,10 @@ these specifications_.
 The format of the returned object is similar to that returned by
 ``read_yanny()`` in the efftickle perl package (in the yannytools product).
 
-Currently multidimensional arrays are only supported for type ``char``, but a
+Currently multidimensional arrays are only supported for type ``char``, and a
 close reading of the specifications indicates that multidimensional arrays
-were only ever intended to be supported for type ``char``.
+were only ever intended to be supported for type ``char``.  So no
+multidimensional arrays, sorry.
 
 .. _specifications: http://www.sdss3.org/dr8/software/par.php
 """
@@ -100,8 +101,9 @@ class yanny(dict):
 
         Examples
         --------
-        >>> pydl.pydlutils.yanny.yanny.get_token("The quick brown fox")
-        ('The','quick brown fox')
+        >>> from pydl.pydlutils.yanny import yanny
+        >>> yanny.get_token("The quick brown fox")
+        ('The', 'quick brown fox')
         """
         if string[0] == '"':
             (word, remainder) = re.search(r'^"([^"]*)"\s*(.*)',
@@ -138,11 +140,17 @@ class yanny(dict):
 
         Examples
         --------
-        >>> yanny.yanny.protect('This string contains whitespace.')
+        >>> from pydl.pydlutils.yanny import yanny
+        >>> yanny.protect('This string contains whitespace.')
         '"This string contains whitespace."'
+        >>> yanny.protect('This string contains a #hashtag.')
+        '"This string contains a #hashtag."'
         """
-        s = str(x)
-        if len(s) == 0 or re.search(r'\s+',s) is not None:
+        if isinstance(x,numpy.bytes_):
+            s = x.decode()
+        else:
+            s = str(x)
+        if len(s) == 0 or s.find('#') >= 0 or re.search(r'\s+',s) is not None:
             return '"' + s + '"'
         else:
             return s
@@ -150,7 +158,59 @@ class yanny(dict):
     #
     #
     @staticmethod
-    def dtype_to_struct(dt,structname='mystruct',enums=dict()):
+    def trailing_comment(line):
+        """Identify a trailing comment and strip it.
+
+        This routine works on the theory that a properly quoted comment mark
+        will be surrounted by an odd number of double quotes, & we can
+        skip to searching for the last one in the line.
+
+        Parameters
+        ----------
+        line : str
+            A line from a yanny file potentially containing trailing comments.
+
+        Returns
+        -------
+        trailing_comment : str
+            The line with any trailing comment and any residual white space
+            trimmed off.
+
+        Bugs
+        ----
+        This may fail in certain pathological cases, for example if a
+        real trailing comment contains a single double-quote::
+
+            # a 'pathological" trailing comment
+
+        or if someone is over-enthusiastically commenting::
+
+            # # # # # I like # characters.
+
+        Examples
+        --------
+        >>> from pydl.pydlutils.yanny import yanny
+        >>> yanny.trailing_comment('mystruct 1234 "#hashtag" # a comment.')
+        'mystruct 1234 "#hashtag"'
+        >>> yanny.trailing_comment('mystruct 1234 "#hashtag" # a "comment".')
+        'mystruct 1234 "#hashtag"'
+        """
+        lastmark = line.rfind('#')
+        if lastmark >= 0:
+            #
+            # Count the number of double quotes in the remainder of the line
+            #
+            if (len([c for c in line[lastmark:] if c == '"']) % 2) == 0:
+                #
+                # Even number of quotes
+                #
+                return line[0:lastmark].rstrip()
+        return line
+    #
+    #
+    #
+    @staticmethod
+    def dtype_to_struct(dt,structname='mystruct',enums=None):
         """Convert a NumPy dtype object describing a record array to
         a typedef struct statement.
 
@@ -181,15 +241,16 @@ class yanny(dict):
         dtmap = {'i2':'short','i4':'int','i8':'long','f4':'float',
             'f8':'double'}
         returnenums = list()
-        for e in enums:
-            lines = list()
-            lines.append('typedef enum {')
-            for n in enums[e][1]:
-                lines.append("    {0},".format(n))
-            lines[-1] = lines[-1].strip(',')
-            lines.append('}} {0};'.format(enums[e][0].upper()))
-            returnenums.append("\n".join(lines))
-            #lines.append('')
+        if enums is not None:
+            for e in enums:
+                lines = list()
+                lines.append('typedef enum {')
+                for n in enums[e][1]:
+                    lines.append("    {0},".format(n))
+                lines[-1] = lines[-1].strip(',')
+                lines.append('}} {0};'.format(enums[e][0].upper()))
+                returnenums.append("\n".join(lines))
+                #lines.append('')
         lines = list()
         lines.append('typedef struct {')
         for c in dt.names:
@@ -333,16 +394,6 @@ class yanny(dict):
             return None
         if variable not in self.columns(structure):
             return None
-        defl = filter(lambda x: x.find(structure.lower()) > 0,
-            self['symbols']['struct'])
-        defu = filter(lambda x: x.find(structure.upper()) > 0,
-            self['symbols']['struct'])
-        if len(defl) != 1 and len(defu) != 1:
-            return None
-        elif len(defl) == 1:
-            definition = defl
-        else:
-            definition = defu
         #
         # Added code to cache values to speed up parsing large files.
         # 2009.05.11 / Demitri Muna, NYU
@@ -361,6 +412,14 @@ class yanny(dict):
         except KeyError:
             if self.debug:
                 print(variable)
+            defl = [ x for x in self['symbols']['struct'] if x.find(structure.lower()) > 0 ]
+            defu = [ x for x in self['symbols']['struct'] if x.find(structure.upper()) > 0 ]
+            if len(defl) != 1 and len(defu) != 1:
+                return None
+            elif len(defl) == 1:
+                definition = defl
+            else:
+                definition = defu
             typere = re.compile(r'(\S+)\s+{0}([[<].*[]>]|);'.format(variable))
             (typ,array) = typere.search(definition[0]).groups()
             var_type = typ + array.replace('<','[').replace('>',']')
@@ -513,9 +572,9 @@ class yanny(dict):
             return int(typ[typ.rfind('[')+1:typ.rfind(']')])
         except ValueError:
             if self.isarray(structure,variable):
-                return max([max(map(len,r)) for r in self[structure][variable]])
+                return max([max([len(x) for x in r]) for r in self[structure][variable]])
             else:
-                return max(map(len,self[structure][variable]))
+                return max([len(x) for x in self[structure][variable]])
     #
     #
     #
@@ -542,7 +601,7 @@ class yanny(dict):
             if typ == 'char':
                 d = "S{0:d}".format(self.char_length(structure,c))
             elif self.isenum(structure,c):
-                d = "S{0:d}".format(max(map(len,self._enum_cache[typ])))
+                d = "S{0:d}".format(max([len(x) for x in self._enum_cache[typ]]))
             else:
                 d = dtmap[typ]
             if self.isarray(structure,c):
@@ -582,17 +641,17 @@ class yanny(dict):
         typ = self.basetype(structure,variable)
         if (typ == 'short' or typ == 'int'):
             if self.isarray(structure,variable):
-                return map(int, value)
+                return [int(v) for v in value]
             else:
                 return int(value)
         if typ == 'long':
             if self.isarray(structure,variable):
-                return map(long, value)
+                return [long(v) for v in value]
             else:
                 return long(value)
         if (typ == 'float' or typ == 'double'):
             if self.isarray(structure,variable):
-                return map(float, value)
+                return [float(v) for v in value]
             else:
                 return float(value)
         return value
@@ -605,9 +664,10 @@ class yanny(dict):
         This is just the list of keys of the object with the 'internal'
         keys removed.
         """
-        foo = self['symbols'].keys()
-        foo.remove('struct')
-        foo.remove('enum')
+        foo = list()
+        for k in self['symbols'].keys():
+            if k not in ('struct','enum'):
+                foo.append(k)
         return foo
     #
     #
@@ -661,9 +721,8 @@ class yanny(dict):
         p = list()
         foo = self.tables()
         for k in self.keys():
-            if k == 'symbols' or k in foo:
-                continue
-            p.append(k)
+            if k != 'symbols' and k not in foo:
+                p.append(k)
         return p
     #
     #
@@ -676,7 +735,7 @@ class yanny(dict):
         If the yanny object instance is set up for NumPy record arrays, then
         a single row can be obtained with::
 
-            >>> row0 = par['TABLE'][0]
+            row0 = par['TABLE'][0]
 
         Parameters
         ----------
@@ -708,7 +767,7 @@ class yanny(dict):
         If the yanny object instance is set up for NumPy record arrays, then
         the same functionality can be obtained with::
 
-            >>> foo = par['TABLE'][0]['column']
+            foo = par['TABLE'][0]['column']
 
         Parameters
         ----------
@@ -748,7 +807,13 @@ class yanny(dict):
 
         Read a yanny file and return only the pairs::
 
-            >>> new_dict = yanny.yanny(file).new_dict_from_pairs()
+            >>> from os.path import dirname
+            >>> from pydl.pydlutils.yanny import yanny
+            >>> new_dict = yanny(dirname(__file__)+'/tests/t/test.par').new_dict_from_pairs()
+            >>> new_dict['mjd']
+            '54579'
+            >>> new_dict['alpha']
+            'beta gamma delta'
 
         added: Demitri Muna, NYU 2009-04-28
         """
@@ -759,7 +824,7 @@ class yanny(dict):
     #
     #
     #
-    def write(self,newfile=None):
+    def write(self,newfile=None,comments=None):
         """Write a yanny object to a file.
 
         This assumes that the filename used to create the object was not that
@@ -775,15 +840,26 @@ class yanny(dict):
         ----------
         newfile : str, optional
             The name of the file to write.
+        comments : str or list of str, optional
+            Comments that will be placed at the head of the file.  If a
+            single string is passed, it will be written out verbatim, so it
+            had better contain '#' characters.  If a list of strings is
+            passed, comment characters will be added and the strings
+            will be joined together.
         """
         if newfile is None:
             if len(self.filename) > 0:
                 newfile = self.filename
             else:
                 raise ValueError("No filename specified!")
-        basefile = os.path.basename(newfile)
-        timestamp = datetime.datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S UTC')
-        contents = "#\n# {0}\n#\n# Created by yanny.py\n#\n# {1}\n#\n".format(basefile,timestamp)
+        if comments is None:
+            basefile = os.path.basename(newfile)
+            timestamp = datetime.datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S UTC')
+            comments = "#\n# {0}\n#\n# Created by pydl.pydlutils.yanny.yanny\n#\n# {1}\n#\n".format(basefile,timestamp)
+        else:
+            if not isinstance(comments, str):
+                comments = "\n".join(["# {0}".format(c) for c in comments]) + "\n"
+        contents = comments
         #
         # Print any key/value pairs
         #
@@ -810,7 +886,7 @@ class yanny(dict):
                 line.append(sym)
                 for col in columns:
                     if self.isarray(sym,col):
-                        datum = '{' + ' '.join(map(self.protect,self[sym][col][k])) + '}'
+                        datum = '{' + ' '.join([self.protect(x) for x in self[sym][col][k]]) + '}'
                     else:
                         datum = self.protect(self[sym][col][k])
                     line.append(datum)
@@ -874,7 +950,7 @@ class yanny(dict):
                     line.append(sym)
                     for col in columns:
                         if self.isarray(sym,col):
-                            datum = '{' + ' '.join(map(self.protect,datatable[datasym][col][k])) + '}'
+                            datum = '{' + ' '.join([self.protect(x) for x in datatable[datasym][col][k]]) + '}'
                         else:
                             datum = self.protect(datatable[datasym][col][k])
                         line.append(datum)
@@ -974,7 +1050,11 @@ class yanny(dict):
                 self[name.upper()][column] = list()
         comments = re.compile(r'^\s*#') # Remove lines containing only comments
         blanks = re.compile(r'^\s*$') # Remove lines containing only whitespace
-        trailing_comments = re.compile(r'\s*\#.*$') # Remove trailing comments
+        #
+        # Remove trailing comments, but not if they are enclosed in quotes.
+        #
+        #trailing_comments = re.compile(r'\s*\#.*$')
+        #trailing_comments = re.compile(r'\s*\#[^"]+$')
         double_braces = re.compile(r'\{\s*\{\s*\}\s*\}') # Double empty braces get replaced with empty quotes
         if len(lines) > 0:
             for line in lines.split('\n'):
@@ -990,7 +1070,8 @@ class yanny(dict):
                 # Remove leading & trailing blanks & comments
                 #
                 line = line.strip()
-                line = trailing_comments.sub('',line)
+                line = self.trailing_comment(line)
+                #line = trailing_comments.sub('',line)
                 line = double_braces.sub('""',line)
                 #
                 # Now if the first word on the line does not match a
