@@ -1,5 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function, unicode_literals
+#
 def smooth(signal,owidth,edge_truncate=False):
     """Replicates the IDL SMOOTH() function.
 
@@ -36,9 +38,9 @@ def smooth(signal,owidth,edge_truncate=False):
     if width < 3:
         return signal
     n = signal.size
-    istart = (width-1)/2
-    iend = n - (width+1)/2
-    w2 = width/2
+    istart = int((width-1)/2)
+    iend = n - int((width+1)/2)
+    w2 = int(width/2)
     s = signal.copy()
     for i in range(n):
         if i < istart:
